aboutsummaryrefslogtreecommitdiffstats
path: root/contrib/python/Pillow/py3/PIL/BmpImagePlugin.py
diff options
context:
space:
mode:
authorAlexSm <alex@ydb.tech>2024-01-26 16:00:50 +0100
committerGitHub <noreply@github.com>2024-01-26 16:00:50 +0100
commit7ebcfd058d924bcc8c23da70e034f7415687885c (patch)
treee4f00d163c77528c1855f2d7af54a8be83fc1ccb /contrib/python/Pillow/py3/PIL/BmpImagePlugin.py
parent64ca2dcd06312b9eef624054ceb5f787e11be79a (diff)
parent6d79e7793c2c462134f4b4a7d911abc7b9b0766f (diff)
downloadydb-7ebcfd058d924bcc8c23da70e034f7415687885c.tar.gz
Merge pull request #1260 from ydb-platform/mergelibs10
mergelibs10
Diffstat (limited to 'contrib/python/Pillow/py3/PIL/BmpImagePlugin.py')
-rw-r--r--contrib/python/Pillow/py3/PIL/BmpImagePlugin.py14
1 files changed, 7 insertions, 7 deletions
diff --git a/contrib/python/Pillow/py3/PIL/BmpImagePlugin.py b/contrib/python/Pillow/py3/PIL/BmpImagePlugin.py
index 9abfd0b5b8..6f730cfef1 100644
--- a/contrib/python/Pillow/py3/PIL/BmpImagePlugin.py
+++ b/contrib/python/Pillow/py3/PIL/BmpImagePlugin.py
@@ -22,7 +22,7 @@
#
# See the README file for information on usage and redistribution.
#
-
+from __future__ import annotations
import os
@@ -230,21 +230,21 @@ class BmpImageFile(ImageFile.ImageFile):
else:
padding = file_info["palette_padding"]
palette = read(padding * file_info["colors"])
- greyscale = True
+ grayscale = True
indices = (
(0, 255)
if file_info["colors"] == 2
else list(range(file_info["colors"]))
)
# ----------------- Check if greyscale and ignore palette if so
for ind, val in enumerate(indices):
rgb = palette[ind * padding : ind * padding + 3]
if rgb != o8(val) * 3:
- greyscale = False
+ grayscale = False
- # ------- If all colors are grey, white or black, ditch palette
- if greyscale:
+ # ------- If all colors are gray, white or black, ditch palette
+ if grayscale:
self._mode = "1" if file_info["colors"] == 2 else "L"
raw_mode = self.mode
else:
@@ -396,7 +396,7 @@ def _save(im, fp, filename, bitmap_header=True):
dpi = info.get("dpi", (96, 96))
# 1 meter == 39.3701 inches
- ppm = tuple(map(lambda x: int(x * 39.3701 + 0.5), dpi))
+ ppm = tuple(int(x * 39.3701 + 0.5) for x in dpi)
stride = ((im.size[0] * bits + 7) // 8 + 3) & (~3)
header = 40 # or 64 for OS/2 version 2
@@ -230,21 +230,21 @@ class BmpImageFile(ImageFile.ImageFile):
else list(range(file_info["colors"]))
)
- # ----------------- Check if greyscale and ignore palette if so
+ # ----------------- Check if grayscale and ignore palette if so
for ind, val in enumerate(indices):
rgb = palette[ind * padding : ind * padding + 3]